@@ -1,5 +1,5 @@
 package MooseX::NonMoose;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Moose ();
 use Moose::Exporter;
@@ -10,7 +10,7 @@ MooseX::NonMoose - easy subclassing of non-Moose classes
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -59,11 +59,11 @@ for extending non-Moose modules. L<MooseX::NonMoose::Meta::Role::Class> and
 L<MooseX::NonMoose::Meta::Role::Constructor> can also be applied to your
 metaclasses manually, either by passing a C<-traits> option to your C<use
 Moose;> line, or by applying them using L<Moose::Util::MetaRole> in a
-L<Moose::Exporter>-based class. L<MooseX::NonMoose::Meta::Role::Class> is the
+L<Moose::Exporter>-based package. L<MooseX::NonMoose::Meta::Role::Class> is the
 part that provides the main functionality of this module; if you don't care
 about inlining, this is all you need to worry about. Applying
 L<MooseX::NonMoose::Meta::Role::Constructor> as well will provide an inlined
-constructor, when you immutabilize your class.
+constructor when you immutabilize your class.
 
 =cut
 
@@ -82,17 +82,6 @@ sub init_meta {
     return Class::MOP::class_of($options{for_class});
 }
 
-=head1 AUTHOR
-
-  Jesse Luehrs <doy at tozt dot net>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2009 by Jesse Luehrs.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
-
 =head1 TODO
 
 =over 4
@@ -110,7 +99,7 @@ subclass of a class whose constructor does strict argument checking.
 =over 4
 
 =item * The reference that the non-Moose class uses as its instance type B<must>
-match the instance type that Moose is using (currently, Moose only supports
+match the instance type that Moose is using (currently, Moose defaults to
 hashref based instances).
 
 =item * Arguments passed to the constructor will be passed as-is to the
@@ -138,7 +127,7 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=MooseX-NonMoose>.
 L<Moose::Cookbook::FAQ/How do I make non-Moose constructors work with Moose?>
 
 L<MooseX::Alien> - serves the same purpose, but with a radically different (and
-far more hackish and worse) implementation.
+far more hackish) implementation.
 
 =head1 SUPPORT
 
@@ -168,6 +157,17 @@ L<http://search.cpan.org/dist/MooseX-NonMoose>
 
 =back
 
+=head1 AUTHOR
+
+  Jesse Luehrs <doy at tozt dot net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Jesse Luehrs.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as perl itself.
+
 =cut
 
 1;
\ No newline at end of file
